# Clinv

[![Actions Status](https://github.com/lyz-code/clinv/workflows/Tests/badge.svg)](https://github.com/lyz-code/clinv/actions)
[![Actions Status](https://github.com/lyz-code/clinv/workflows/Build/badge.svg)](https://github.com/lyz-code/clinv/actions)
[![Coverage Status](https://coveralls.io/repos/github/lyz-code/clinv/badge.svg?branch=master)](https://coveralls.io/github/lyz-code/clinv?branch=master)

DevSecOps command line asset inventory

## Help

See [documentation](https://lyz-code.github.io/clinv) for more details.

## Installing

```bash
pip install clinv
```

## Contributing

For guidance on setting up a development environment, and how to make
a contribution to *clinv*, see [Contributing to
clinv](https://lyz-code.github.io/clinv/contributing).

## License

GPLv3
